@@ -1,9 +1,9 @@
 package Music::Duration;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Add 32nd, 64th and tuple durations to MIDI-Perl
+# ABSTRACT: Add 32nd, 64th and tuplet durations to MIDI-Perl
 
-our $VERSION = '0.0604';
+our $VERSION = '0.0605';
 use strict;
 use warnings;
 
@@ -57,11 +57,11 @@ __END__
 
 =head1 NAME
 
-Music::Duration - Add 32nd, 64th and tuple durations to MIDI-Perl
+Music::Duration - Add 32nd, 64th and tuplet durations to MIDI-Perl
 
 =head1 VERSION
 
-version 0.0604
+version 0.0605
 
 =head1 SYNOPSIS
 
@@ -73,7 +73,7 @@ version 0.0604
   use MIDI::Simple;
   use Music::Duration;
 
-  Music::Duration::tuplet( 'ten', 'z', 5 ); # 5 notes in place of an eighth note triplet
+  Music::Duration::tuplet( 'ten', 'z', 5 ); # 5 divisions in place of an eighth note triplet
 
   my $black_page = MIDI::Simple->new_score();
   # ...
@@ -82,16 +82,22 @@ version 0.0604
 =head1 DESCRIPTION
 
 This module adds thirty-second and sixty-fourth note divisions to
-L<MIDI::Simple>.  It also adds fractional note divisions with the B<tuplet()>
-function.
+L<MIDI::Simple> C<%Length>.  It also adds fractional note divisions with the
+B<tuplet()> function.
 
 32nd durations added:
 
-  yn dyn ddyn tyn
+  yn:   thirty-second note
+  dyn:  dotted thirty-second note
+  ddyn: double dotted thirty-second note
+  tyn:  thirty-second note triplet
 
 64th durations added:
 
-  xn dxn ddxn txn
+  xn:   sixty-fourth note
+  dxn:  dotted sixty-fourth note
+  ddxn: double dotted sixty-fourth note
+  txn:  sixty-fourth note triplet
 
 =head1 FUNCTION
 
@@ -99,7 +105,7 @@ function.
 
   Music::Duration::tuplet( 'qn', 'z', 5 );
   # $score->n( 'zqn', ... );
-  Music::Duration::tuplet( 'wn', 'z', 5 );
+  Music::Duration::tuplet( 'wn', 'z', 7 );
   # $score->n( 'zwn', ... );
 
 Add a fractional division to the L<MIDI::Simple> C<Length> hash for a given
@@ -111,7 +117,7 @@ A triplet is a 3-tuplet.
 
 So in the first example, instead of a quarter note, we instead play 5 beats - a
 5-tuple.  In the second, instead of a whole note (of four beats), we instead
-play 5 beats.
+play 7 beats.
 
 =head2 tuple()
 
@@ -119,12 +125,14 @@ Synonym for the B<tuplet> function.
 
 =head1 SEE ALSO
 
-The C<Length> hash in L<MIDI::Simple>
+The C<%Length> hash in L<MIDI::Simple>
 
-The code in the C<t/> directory
+The code in the F<eg/> and F<t/> directories
 
 L<https://www.scribd.com/doc/26974069/Frank-Zappa-The-Black-Page-1-Melody-Score>
 
+L<https://en.wikipedia.org/wiki/Tuplet>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
